darkhistory.electrons.ics.engloss_diff_terms — DarkHistory documentation

# darkhistory.electrons.ics.engloss_diff_terms

Functions for computing the ICS energy loss spectrum by small parameter expansion.

Functions

`engloss_diff_expansion`(beta, delta, T[, …]) | Difference expansion term for the energy loss spectrum.

#### Previous topic

darkhistory.electrons.ics.BE_integrals.F_x_log_a

#### Next topic

darkhistory.electrons.ics.engloss_diff_terms.engloss_diff_expansion

### This Page

Show Source